@@ -11,7 +11,7 @@ as.date <- function(x, order = "mdy", ...) {
                    "dmy" = c(3, 2, 1),
                    stop("Invalid value for 'order' option"))
 	nn <- length(x)
-	temp <- .C(R_char_date,
+	temp <- .C(char_date,
                    as.integer(nn),
                    as.integer(order.vec),
                    as.character(x),
